==> haskell-universe-reverse-instances-1.1.2-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-reverse-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-reverse-instances
version:              1.1.2
visibility:           public
id:                   universe-reverse-instances-1.1.2-97zDsA1iUgt1Ac5lWuRrze
key:                  universe-reverse-instances-1.1.2-97zDsA1iUgt1Ac5lWuRrze
license:              BSD-3-Clause
copyright:            Daniel Wagner 2014
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:
    Instances of standard classes that are made possible by enumerations

description:
    For example this package provides a @Eq (a -> b)@ instance:

    @
    instance (Finite a, Eq b) => Eq (a -> b) where
    f == g = and [f x == g x | x <- universeF]
    @

category:             Data
abi:                  fe86a4de3cde8d285d225ed84396b2b4
exposed:              True
exposed-modules:
    Data.Universe.Instances.Eq Data.Universe.Instances.Ord
    Data.Universe.Instances.Read Data.Universe.Instances.Show
    Data.Universe.Instances.Traversable

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-reverse-instances
hs-libraries:         HSuniverse-reverse-instances-1.1.2-97zDsA1iUgt1Ac5lWuRrze
depends:
    base-4.17.2.1 containers-0.6.7
    universe-base-1.1.4-8YQ9pbCSaZh26CSBZWsfcG

haddock-interfaces:
    /usr/share/doc/haskell-universe-reverse-instances/html/universe-reverse-instances.haddock

haddock-html:         /usr/share/doc/haskell-universe-reverse-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-universe-reverse-instances-1.1.2-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-reverse-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-reverse-instances
version:              1.1.2
visibility:           public
id:                   universe-reverse-instances-1.1.2-4dV6jXTFhK6BwfO3hp6hzZ
key:                  universe-reverse-instances-1.1.2-4dV6jXTFhK6BwfO3hp6hzZ
license:              BSD-3-Clause
copyright:            Daniel Wagner 2014
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:
    Instances of standard classes that are made possible by enumerations

description:
    For example this package provides a @Eq (a -> b)@ instance:

    @
    instance (Finite a, Eq b) => Eq (a -> b) where
    f == g = and [f x == g x | x <- universeF]
    @

category:             Data
abi:                  35c8b2dc3c68771b20177ba3d2d94c8c
exposed:              True
exposed-modules:
    Data.Universe.Instances.Eq Data.Universe.Instances.Ord
    Data.Universe.Instances.Read Data.Universe.Instances.Show
    Data.Universe.Instances.Traversable

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-reverse-instances
hs-libraries:         HSuniverse-reverse-instances-1.1.2-4dV6jXTFhK6BwfO3hp6hzZ
depends:
    base-4.17.2.1 containers-0.6.7
    universe-base-1.1.4-6qYHwPV864X1M3YTma827K

haddock-interfaces:
    /usr/share/doc/haskell-universe-reverse-instances/html/universe-reverse-instances.haddock

haddock-html:         /usr/share/doc/haskell-universe-reverse-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
